@@ -4,13 +4,18 @@ use strict;
 use warnings;
 use base qw( CLI::Dispatch::Command );
 use Class::Unload;
+use Class::Inspector;
 use Encode;
 use Pod::Simple::Text;
 use Path::Extended;
 use String::CamelCase;
 use Term::Encoding ();
+use Try::Tiny;
+
+my $term_encoding = eval {
+  find_encoding(Term::Encoding::get_encoding())
+} || 'utf8';
 
-my $term_encoding = Term::Encoding::get_encoding();
 
 sub options {qw( from|decode=s to|encode=s )}
 
@@ -108,19 +113,23 @@ sub list_commands {
 
         # check availability
         if ( $pmfile->exists ) {
-          Class::Unload->unload($class);
-          eval "require $class";
-          if ($@) {
+          my $loaded = Class::Inspector->loaded($class);
+          Class::Unload->unload($class) if $loaded;
+          my $error;
+          try   { eval "require $class" or die }
+          catch { $error = $_ || 'Obscure error' };
+          if ($error) {
             $found{$basename} .= " [disabled: compile error]";
           }
           elsif ( $class->can('check') ) {
-            eval { $class->check };
-            if ($@) {
-              my $error = $@;
+            try   { $class->check }
+            catch {
+              $error = $_ || 'Obscure error';
               $error =~ s/\s+at .+? line \d+\.?\s*$//;
               $found{$basename} .= " [disabled: $error]";
-            }
+            };
           }
+          Class::Unload->unload($class) unless $loaded;
         }
 
         my $len = length $basename;
